@@ -17,7 +17,7 @@ sub run ($self) {
     return if !$self->_can_release;
 
     # create new version
-    my $cur_ver = $self->dist->id->{current_release} // 'v0.0.0';
+    my $cur_ver = $self->dist->id->{release};
 
     my $new_ver = $self->_compose_new_version;
 
@@ -200,42 +200,42 @@ sub run ($self) {
 
 sub _can_release ($self) {
     if ( !$self->dist->scm ) {
-        say q[SCM is required];
+        say q[SCM is required.];
 
         return;
     }
 
     # check for uncommited changes
     if ( !$self->dist->is_commited ) {
-        say q[Working copy or sub-repositories has uncommited changes or unknown files];
+        say q[Working copy or sub-repositories has uncommited changes or unknown files.];
 
         return;
     }
 
     # check distance from the last release
-    if ( !$self->dist->id->{current_release_distance} ) {
-        say q[No changes to release];
+    if ( !$self->dist->id->{release_distance} ) {
+        say q[No changes since latest release.];
 
         return;
     }
 
     if ( $self->dist->cfg->{dist}->{cpan} && !$ENV->user_cfg->{'Pcore::API::PAUSE'}->{username} || !$ENV->user_cfg->{'Pcore::API::PAUSE'}->{password} ) {
-        say q[You need to specify PAUSE credentials];
+        say q[You need to specify PAUSE credentials.];
 
         return;
     }
 
     if ( $self->dist->docker_cfg ) {
         if ( !$ENV->user_cfg->{'Pcore::API::DockerHub'}->{api_username} || !$ENV->user_cfg->{'Pcore::API::DockerHub'}->{api_password} ) {
-            say q[You need to specify DockerHub credentials];
+            say q[You need to specify DockerHub credentials.];
 
             return;
         }
 
         my $dockerfile = P->file->read_bin( $self->dist->root . 'Dockerfile' );
 
-        if ( $dockerfile->$* !~ m[^FROM\s+[^:]+:v\d+[.]\d+[.]\d+$]smi ) {
-            say q[Dockerfile base image must contains version tag];
+        if ( $dockerfile->$* !~ m[^FROM\s+[^:]+:v\d+[.]\d+[.]\d+$]sm ) {
+            say q[Dockerfile base image must contain version tag. Use "pcore docker --from <TAG>".];
 
             return;
         }
@@ -247,16 +247,12 @@ sub _can_release ($self) {
 sub _compose_new_version ($self) {
 
     # show current and new versions, take confirmation
-    my $cur_ver = $self->dist->id->{current_release};
+    my $cur_ver = $self->dist->id->{release};
 
-    if ( !$cur_ver ) {
-        if ( $self->bugfix ) {
-            say 'Bugfix has no sense on first release';
+    if ( $cur_ver eq 'v0.0.0' && $self->bugfix ) {
+        say 'Bugfix has no sense on first release';
 
-            return;
-        }
-
-        $cur_ver = 'v0.0.0';
+        return;
     }
 
     my ( $major, $minor, $bugfix ) = $cur_ver =~ /v(\d+)[.](\d+)[.](\d+)/sm;
@@ -377,12 +373,12 @@ sub _create_changes ( $self, $ver, $issues ) {
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    3 | 53, 188              | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 354                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 350                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    2 | 27, 30, 38, 43, 65,  | ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    |
 ## |      | 85, 99, 147          |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 350                  | BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                |
+## |    1 | 346                  | BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
