@@ -73,9 +73,9 @@ sub CLI_RUN ( $self, $opt, $arg, $rest ) {
                         width => 14,
                         align => 1,
                     },
-                    commited => {
-                        width => 10,
-                        align => 0,
+                    uncommited => {
+                        width => 15,
+                        align => 1,
                     },
                 ],
             );
@@ -87,25 +87,25 @@ sub CLI_RUN ( $self, $opt, $arg, $rest ) {
 
                 push @row, $dist->name;
 
-                if ( !defined $dist->id->{current_release} ) {
+                if ( $dist->id->{release} eq 'v0.0.0' ) {
                     push @row, WHITE . ON_RED . ' unreleased ' . RESET;
                 }
                 else {
-                    push @row, $dist->id->{current_release};
+                    push @row, $dist->id->{release};
                 }
 
-                if ( $dist->id->{current_release_distance} ) {
-                    push @row, WHITE . ON_RED . sprintf( ' %3s ', $dist->id->{current_release_distance} ) . RESET;
+                if ( $dist->id->{release_distance} ) {
+                    push @row, WHITE . ON_RED . sprintf( ' %3s ', $dist->id->{release_distance} ) . RESET;
                 }
                 else {
-                    push @row, q[];
+                    push @row, q[ - ];
                 }
 
                 if ( !$dist->is_commited ) {
-                    push @row, WHITE . ON_RED . ' no ' . RESET;
+                    push @row, WHITE . ON_RED . ' uncommited ' . RESET;
                 }
                 else {
-                    push @row, q[];
+                    push @row, q[ - ];
                 }
 
                 print $tbl->render_row( \@row );
@@ -125,18 +125,30 @@ sub run ( $self ) {
 }
 
 sub _show_dist_info ( $self, $dist ) {
-    my $tmpl = <<'TMPL';
-name: <: $dist.name :>
-version: <: $dist.version :>
-revision: <: $dist.id.node :>
-is CPAN dist: <: $dist.is_cpan_dist :>
-module_name: <: $dist.module.name :>
-root: <: $dist.root :>
-share_dir: <: $dist.share_dir :>
-lib_dir: <: $dist.module.lib :>
-TMPL
+    say $dist->version_string;
 
-    say P->tmpl->render( \$tmpl, { dist => $dist } )->$*;
+    my $tbl = P->text->table(
+        header => 0,
+        grid   => undef,
+        style  => 'compact',
+        width  => 100,
+        cols   => [
+            1 => {
+                width => 10,
+                align => -1,
+            },
+            2 => { align => -1, },
+        ],
+    );
+
+    print $tbl->render_all(
+        [    #
+            [ module => $dist->module->name, ],
+            [ root   => $dist->root, ],
+            [ lib    => $dist->module->lib, ],
+            [ share  => $dist->share_dir, ]
+        ]
+    );
 
     return;
 }
